# ava-fixture

[![NPM version][npm-image]][npm-url]
[![NPM downloads][downloads-image]][downloads-url]
[![Build status][travis-image]][travis-url]
[![Coverage Status][coveralls-image]][coveralls-url]

Helps you to easily write fixture tests with [`ava`](https://github.com/avajs/ava).

## What is Fixture Test

Fixture tests are tests that require access to some files.
The tests may write files and in that case the files can be compared with a baseline (i.e. Baseline Tests)

## Usage

Assume you have the following folders:

```sh
+ fixtures
  + cases
    + case-1
      - something.txt
    + other-cases
  + baselines
    + case-1
      - something.txt
  + results # empty, not check into repository
```

When you only need to access files in each test case (i.e. don't need to perform baseline test):

```ts
import ava from 'ava';
import fixture from 'ava-fixture';

// Point to the base folder which contain the fixtures.
// Relative path starts from project root.
const ftest = fixture(ava, 'fixture/cases');

// You can also use absolute path.
// const ftest = fixture(ava, join(process.cwd(), 'fixture/cases'));

ftest('test title', 'case-1', (t) => {
  // t is ava test.
  // process.cwd() points to `case-1`

  // ...test away
});
```

When you want to perform baseline tests:

```ts
import test from 'ava';
import fixture from 'ava-fixture';

// Point to the base folder which contain the fixtures.
// Relative path starts from project root.
const btest = fixture(test, 'fixture/cases', 'fixture/baselines', 'fixture/results');

btest('test title', 'case-1', (t, d) => {
  // t is ava test.
  // process.cwd() points to `case-1`
  // d.casePath, d.baselinePath, d.resultPath points to respective folder for `case-1`
  // ...do tests

  // `d.match()` will check if the result folder has the same content as the baseline folder.
  return d.match()
});
```

## Other API

```ts
import test from 'ava';
import fixture from 'ava-fixture';

const ftest = fixture(test, 'fixture/cases');

ftest.only(...)
ftest.skip(...)
```

For `before()`, `beforeEach()`, `after()`, `afterEach()`, `todo()`, use `ava` directly.

## Contribute

```sh
# right after clone
npm install

# begin making changes
git checkout -b <branch>
npm run watch

# edit `webpack.config.dev.js` to exclude dependencies for the global build.

# after making change(s)
git commit -m "<commit message>"
git push

# create PR
```

## Npm Commands

There are a few useful commands you can use during development.

```sh
# Run tests (and lint) automatically whenever you save a file.
npm run watch

# Run tests with coverage stats (but won't fail you if coverage does not meet criteria)
npm run test

# Manually verify the project.
# This will be ran during 'npm preversion' so you normally don't need to run this yourself.
npm run verify

# Build the project.
# You normally don't need to do this.
npm run build

# Run tslint
# You normally don't need to do this as `npm run watch` and `npm version` will automatically run lint for you.
npm run lint
```

Generated by [`generator-unional@0.3.1`](https://github.com/unional/unional-cli)

[npm-image]: https://img.shields.io/npm/v/ava-fixture.svg?style=flat
[npm-url]: https://npmjs.org/package/ava-fixture
[downloads-image]: https://img.shields.io/npm/dm/ava-fixture.svg?style=flat
[downloads-url]: https://npmjs.org/package/ava-fixture
[travis-image]: https://img.shields.io/travis/unional/ava-fixture.svg?style=flat
[travis-url]: https://travis-ci.org/unional/ava-fixture
[coveralls-image]: https://coveralls.io/repos/github/unional/ava-fixture/badge.svg
[coveralls-url]: https://coveralls.io/github/unional/ava-fixture
