"use strict";
var path_1 = require("path");
var curryMatch_1 = require("./curryMatch");
function fixture(ava, casesPath, baselinesPath, resultsPath) {
    if (baselinesPath && !resultsPath) {
        throw new Error('baselines and results must be specified together');
    }
    function curry(testfn) {
        return (function (title, caseName, run) {
            if (!run) {
                // name is optional
                run = caseName;
                caseName = title;
            }
            var d = {
                casePath: path_1.resolve(casesPath, caseName)
            };
            if (baselinesPath) {
                d.baselinePath = path_1.resolve(baselinesPath, caseName);
                d.resultPath = path_1.resolve(resultsPath, caseName);
            }
            return testfn((title ? title + ' ' : '') + "(fixture: " + caseName + ")", function (t) {
                var result;
                var cwd = process.cwd();
                try {
                    if (baselinesPath) {
                        d.match = curryMatch_1.curryMatch(d.baselinePath, d.resultPath, t);
                    }
                    process.chdir(d.casePath);
                    result = run(t, d);
                    if (result && result.then) {
                        return result.then(function (r) {
                            process.chdir(cwd);
                            return r;
                        });
                    }
                }
                finally {
                    process.chdir(cwd);
                }
            });
        });
    }
    var fn = curry(ava);
    var others = {
        only: curry(ava.only),
        skip: curry(ava.skip),
        todo: ava.todo
    };
    for (var key in others) {
        fn[key] = others[key];
    }
    return fn;
}
exports.fixture = fixture;
//# sourceMappingURL=fixture.js.map